@@ -5,7 +5,7 @@
  *
  * The MIT License
  *
- * @copyright Copyright (c) 2022 TileDB Inc.
+ * @copyright Copyright (c) 2022-2024 TileDB Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -84,7 +84,6 @@ struct GroupFx {
   void remove_temp_dir(const std::string& path) const;
   std::string get_golden_walk(const std::string& path);
   std::string get_golden_ls(const std::string& path);
-  static std::string random_name(const std::string& prefix);
   std::vector<std::pair<tiledb::sm::URI, tiledb_object_t>> read_group(
       tiledb_group_t* group, bool use_get_member_by_index_v2 = true) const;
   void set_group_timestamp(
@@ -359,13 +358,6 @@ std::string GroupFx::get_golden_ls(const std::string& path) {
   return golden;
 }
 
-std::string GroupFx::random_name(const std::string& prefix) {
-  std::stringstream ss;
-  ss << prefix << "-" << std::this_thread::get_id() << "-"
-     << TILEDB_TIMESTAMP_NOW_MS;
-  return ss.str();
-}
-
 TEST_CASE_METHOD(
     GroupFx, "C API: Test group metadata", "[capi][group][metadata]") {
   // TODO: refactor for each supported FS.
@@ -419,12 +411,14 @@ TEST_CASE_METHOD(
 
 TEST_CASE_METHOD(
     GroupFx,
-    "C API: Group Metadata, write/read",
-    "[capi][group][metadata][read]") {
+    "C API: Group Metadata, write/read, rest",
+    "[capi][group][metadata][rest][regression][sc-4821]") {
   // Create and open group in write mode
   // TODO: refactor for each supported FS.
-  std::string temp_dir = fs_vec_[0]->temp_dir();
-  create_temp_dir(temp_dir);
+  std::string fs_temp_dir = fs_vec_[0]->temp_dir();
+  create_temp_dir(fs_temp_dir);
+  std::string temp_dir =
+      fs_vec_[0]->is_rest() ? "tiledb://unit/" + fs_temp_dir : fs_temp_dir;
 
   std::string group1_uri = temp_dir + "group1";
   REQUIRE(tiledb_group_create(ctx_, group1_uri.c_str()) == TILEDB_OK);
@@ -518,7 +512,7 @@ TEST_CASE_METHOD(
   rc = tiledb_group_close(ctx_, group);
   REQUIRE(rc == TILEDB_OK);
   tiledb_group_free(&group);
-  remove_temp_dir(temp_dir);
+  remove_temp_dir(fs_temp_dir);
 }
 
 TEST_CASE_METHOD(
@@ -1498,6 +1492,54 @@ TEST_CASE_METHOD(
   remove_temp_dir(temp_dir);
 }
 
+TEST_CASE_METHOD(GroupFx, "C API: Group, dump", "[capi][group][dump]") {
+  // Create and open group in write mode
+  // TODO: refactor for each supported FS.
+  std::string temp_dir = fs_vec_[0]->temp_dir();
+  create_temp_dir(temp_dir);
+
+  tiledb::sm::URI group1_uri(temp_dir + "group1");
+  REQUIRE(tiledb_group_create(ctx_, group1_uri.c_str()) == TILEDB_OK);
+
+  tiledb::sm::URI group2_uri(temp_dir + "group2");
+  REQUIRE(tiledb_group_create(ctx_, group2_uri.c_str()) == TILEDB_OK);
+
+  tiledb_group_t* group1;
+  int rc = tiledb_group_alloc(ctx_, group1_uri.c_str(), &group1);
+  REQUIRE(rc == TILEDB_OK);
+  set_group_timestamp(group1, 1);
+  rc = tiledb_group_open(ctx_, group1, TILEDB_WRITE);
+  REQUIRE(rc == TILEDB_OK);
+
+  rc = tiledb_group_add_member(ctx_, group1, group2_uri.c_str(), 0, "group2");
+  REQUIRE(rc == TILEDB_OK);
+  rc = tiledb_group_close(ctx_, group1);
+  REQUIRE(rc == TILEDB_OK);
+
+  // Delete the subgroup to test that recursively dumping its parent will not
+  // fail.
+  rc = tiledb_object_remove(ctx_, group2_uri.c_str());
+  REQUIRE(rc == TILEDB_OK);
+
+  rc = tiledb_group_open(ctx_, group1, TILEDB_READ);
+  REQUIRE(rc == TILEDB_OK);
+
+  char* group_dump;
+  rc = tiledb_group_dump_str(ctx_, group1, &group_dump, 1);
+  REQUIRE(rc == TILEDB_OK);
+  REQUIRE(group_dump != nullptr);
+  REQUIRE(
+      std::string(group_dump) ==
+      "group1 GROUP\n|-- group2 GROUP (does not exist)\n");
+  free(group_dump);
+
+  rc = tiledb_group_close(ctx_, group1);
+  REQUIRE(rc == TILEDB_OK);
+
+  tiledb_group_free(&group1);
+  remove_temp_dir(temp_dir);
+}
+
 #ifdef TILEDB_SERIALIZATION
 TEST_CASE_METHOD(
     GroupFx,
