@@ -251,10 +251,6 @@ template <class T>
 void check_subarray(
     tiledb::Subarray& subarray, const SubarrayRanges<T>& ranges);
 
-template <class T>
-void check_subarray_equiv(
-    tiledb::sm::Subarray& subarray1, tiledb::sm::Subarray& subarray2);
-
 template <class T>
 bool subarray_equiv(
     tiledb::sm::Subarray& subarray1, tiledb::sm::Subarray& subarray2);
@@ -504,7 +500,8 @@ void get_supported_fs(
     bool* s3_supported,
     bool* hdfs_supported,
     bool* azure_supported,
-    bool* gcs_supported);
+    bool* gcs_supported,
+    bool* rest_s3_supported);
 
 /**
  * Opens an array.
