@@ -95,7 +95,6 @@ void vfs_test_remove_temp_dir(
 
 void vfs_test_create_temp_dir(
     tiledb_ctx_t* ctx, tiledb_vfs_t* vfs, const std::string& path);
-
 /**
  * This class defines and manipulates
  * a list of supported filesystems.
@@ -149,6 +148,20 @@ class SupportedFs {
    * @return string directory name
    */
   virtual std::string temp_dir() = 0;
+
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  virtual bool is_rest() = 0;
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  virtual bool is_local() = 0;
 };
 
 /**
@@ -157,10 +170,11 @@ class SupportedFs {
  */
 class SupportedFsS3 : public SupportedFs {
  public:
-  SupportedFsS3()
+  SupportedFsS3(bool rest = false)
       : s3_prefix_("s3://")
       , s3_bucket_(s3_prefix_ + "tiledb-" + random_label() + "/")
-      , temp_dir_(s3_bucket_ + "tiledb_test/") {
+      , temp_dir_(s3_bucket_ + "tiledb_test/")
+      , rest_(rest) {
   }
 
   ~SupportedFsS3() = default;
@@ -204,6 +218,22 @@ class SupportedFsS3 : public SupportedFs {
    */
   virtual std::string temp_dir();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  virtual bool is_rest();
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return false;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -217,6 +247,9 @@ class SupportedFsS3 : public SupportedFs {
 
   /** The directory name of the S3 filesystem. */
   std::string temp_dir_;
+
+  /** If the filesystem is accessed via REST. */
+  bool rest_;
 };
 
 /**
@@ -269,6 +302,24 @@ class SupportedFsHDFS : public SupportedFs {
    */
   virtual std::string temp_dir();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  inline bool is_rest() {
+    return false;
+  }
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return false;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -331,6 +382,24 @@ class SupportedFsAzure : public SupportedFs {
    */
   virtual std::string temp_dir();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  inline bool is_rest() {
+    return false;
+  }
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return false;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -398,6 +467,24 @@ class SupportedFsGCS : public SupportedFs {
    */
   virtual std::string temp_dir();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  inline bool is_rest() {
+    return false;
+  }
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return false;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -478,6 +565,24 @@ class SupportedFsLocal : public SupportedFs {
    */
   std::string file_prefix();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  inline bool is_rest() {
+    return false;
+  }
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return true;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -550,6 +655,24 @@ class SupportedFsMem : public SupportedFs {
    */
   virtual std::string temp_dir();
 
+  /**
+   * Checks if the filesystem is accessed via REST
+   *
+   * @return true if REST, false if not
+   */
+  inline bool is_rest() {
+    return false;
+  }
+
+  /**
+   * Checks if the filesystem is local or remote
+   *
+   * @return true if local, false if not
+   */
+  inline bool is_local() {
+    return true;
+  }
+
  private:
   /* ********************************* */
   /*           ATTRIBUTES              */
@@ -749,6 +872,67 @@ struct TemporaryDirectoryFixture {
   const std::vector<std::unique_ptr<SupportedFs>> supported_filesystems_;
 };
 
+/*
+ * Class to instantiate when setting up a test case to run for all VFSs and
+ * REST
+ *
+ * Example usage: In the beginning of the test define a VFSTestSetup variable
+ * and then just use the Context and the rest of the resources it encapsulates
+ * in the test. The resources will be automatically get freed when the variable
+ * will get out of scope.
+ *
+ * {
+ * tiledb::test::VFSTestSetup vfs_test_setup{"foo_array"};
+ * auto ctx = vfs_test_setup.ctx();
+ * Array array(ctx, array_uri, TILEDB_WRITE);
+ * ...
+ * } // ctx context is destroyed and VFS directories removed
+ *
+ */
+struct VFSTestSetup {
+  VFSTestSetup(tiledb_config_t* config = nullptr)
+      : fs_vec(vfs_test_get_fs_vec())
+      , ctx_c{nullptr}
+      , vfs_c{nullptr}
+      , cfg_c{config} {
+    vfs_test_init(fs_vec, &ctx_c, &vfs_c, cfg_c).ok();
+    temp_dir = fs_vec[0]->temp_dir();
+    vfs_test_create_temp_dir(ctx_c, vfs_c, temp_dir);
+  };
+
+  bool is_rest() {
+    return fs_vec[0]->is_rest();
+  }
+
+  bool is_local() {
+    return fs_vec[0]->is_local();
+  }
+
+  std::string array_uri(const std::string& array_name) {
+    return (
+        fs_vec[0]->is_rest() ? "tiledb://unit/" + temp_dir + array_name :
+                               temp_dir + array_name);
+  }
+
+  Context ctx() {
+    return Context(ctx_c, false);
+  }
+
+  ~VFSTestSetup() {
+    vfs_test_remove_temp_dir(ctx_c, vfs_c, temp_dir);
+    CHECK(vfs_test_close(fs_vec, ctx_c, vfs_c).ok());
+
+    tiledb_ctx_free(&ctx_c);
+    tiledb_vfs_free(&vfs_c);
+  };
+
+  std::vector<std::unique_ptr<SupportedFs>> fs_vec;
+  tiledb_ctx_handle_t* ctx_c;
+  tiledb_vfs_handle_t* vfs_c;
+  tiledb_config_handle_t* cfg_c;
+  std::string temp_dir;
+};
+
 /**
  * Denies write access to a local filesystem path.
  *
