@@ -372,13 +372,11 @@ class StorageManagerCanonical {
   /**
    * Retrieves the encryption type from an array.
    *
-   * @param array_dir The ArrayDirectory object used to retrieve the
-   *     various URIs in the array directory.
+   * @param uri The URI of the array.
    * @param encryption_type Set to the encryption type of the array.
    * @return Status
    */
-  Status array_get_encryption(
-      const ArrayDirectory& array_dir, EncryptionType* encryption_type);
+  Status array_get_encryption(const URI& uri, EncryptionType* encryption_type);
 
   /**
    * Pushes an async query to the queue.
