@@ -695,7 +695,7 @@ Status SubarrayPartitioner::calibrate_current_start_end(bool* must_split_slab) {
   auto dim_num = subarray_.dim_num();
   uint64_t num;
   for (unsigned i = 0; i < dim_num; ++i) {
-    RETURN_NOT_OK(subarray_.get_range_num(i, &num));
+    subarray_.get_range_num(i, &num);
     range_num.push_back(num);
   }
 
@@ -794,8 +794,8 @@ SubarrayPartitioner SubarrayPartitioner::clone() const {
 Status SubarrayPartitioner::compute_current_start_end(bool* found) {
   // Compute the tile overlap. Note that the ranges in `tile_overlap` may have
   // been truncated the ending bound due to memory constraints.
-  RETURN_NOT_OK(subarray_.precompute_tile_overlap(
-      state_.start_, state_.end_, config_, compute_tp_));
+  subarray_.precompute_tile_overlap(
+      state_.start_, state_.end_, config_, compute_tp_);
   const SubarrayTileOverlap* const tile_overlap =
       subarray_.subarray_tile_overlap();
   assert(tile_overlap->range_idx_start() == state_.start_);
@@ -820,13 +820,13 @@ Status SubarrayPartitioner::compute_current_start_end(bool* found) {
   // Compute the estimated result sizes
   std::vector<std::vector<Subarray::ResultSize>> result_sizes;
   std::vector<std::vector<Subarray::MemorySize>> memory_sizes;
-  RETURN_NOT_OK(subarray_.compute_relevant_fragment_est_result_sizes(
+  subarray_.compute_relevant_fragment_est_result_sizes(
       names,
       tile_overlap->range_idx_start(),
       tile_overlap->range_idx_end(),
       &result_sizes,
       &memory_sizes,
-      compute_tp_));
+      compute_tp_);
 
   bool done = false;
   current_.start_ = tile_overlap->range_idx_start();
@@ -932,7 +932,7 @@ void SubarrayPartitioner::compute_splitting_value_on_tiles(
   const Range* r;
   for (auto d : dims) {
     auto dim{array_schema.domain().dimension_ptr(d)};
-    throw_if_not_ok(range.get_range(d, 0, &r));
+    range.get_range(d, 0, &r);
     auto tiles_apart = dim->tile_num(*r) - 1;
     if (tiles_apart != 0) {
       *splitting_dim = d;
@@ -1005,7 +1005,7 @@ void SubarrayPartitioner::compute_splitting_value_single_range(
   const Range* r;
   for (auto d : dims) {
     auto dim{array_schema.dimension_ptr(d)};
-    throw_if_not_ok(range.get_range(d, 0, &r));
+    range.get_range(d, 0, &r);
     if (!r->unary()) {
       *splitting_dim = d;
       dim->splitting_value(*r, splitting_value, unsplittable);
@@ -1050,7 +1050,7 @@ void SubarrayPartitioner::compute_splitting_value_single_range_hilbert(
   // Check for unsplittable again
   auto dim{array_schema.dimension_ptr(*splitting_dim)};
   const Range* r;
-  throw_if_not_ok(range.get_range(*splitting_dim, 0, &r));
+  range.get_range(*splitting_dim, 0, &r);
   if (dim->smaller_than(*splitting_value, *r)) {
     *unsplittable = true;
     return;
@@ -1111,7 +1111,7 @@ Status SubarrayPartitioner::compute_splitting_value_multi_range(
   const Range* r;
   for (auto d : dims) {
     // Check if we need to split the multiple ranges
-    RETURN_NOT_OK(partition.get_range_num(d, &range_num));
+    partition.get_range_num(d, &range_num);
     if (range_num > 1) {
       assert(d == dims.back());
       *splitting_dim = d;
@@ -1121,7 +1121,7 @@ Status SubarrayPartitioner::compute_splitting_value_multi_range(
     }
 
     // Check if we need to split single range
-    throw_if_not_ok(partition.get_range(d, 0, &r));
+    partition.get_range(d, 0, &r);
     auto dim{array_schema.dimension_ptr(d)};
     if (!r->unary()) {
       *splitting_dim = d;
@@ -1160,38 +1160,34 @@ bool SubarrayPartitioner::must_split(Subarray* partition) {
     // Compute max memory sizes
     if (var_size) {
       if (!nullable) {
-        throw_if_not_ok(partition->get_max_memory_size(
+        partition->get_max_memory_size(
             b.first.c_str(),
             &mem_size_fixed,
             &mem_size_var,
             config_,
-            compute_tp_));
+            compute_tp_);
       } else {
-        throw_if_not_ok(partition->get_max_memory_size_nullable(
+        partition->get_max_memory_size_nullable(
             b.first.c_str(),
             &mem_size_fixed,
             &mem_size_var,
             &mem_size_validity,
             config_,
-            compute_tp_));
+            compute_tp_);
       }
     } else {
       if (!nullable) {
-        throw_if_not_ok(partition->get_max_memory_size(
-            b.first.c_str(), &mem_size_fixed, config_, compute_tp_));
+        partition->get_max_memory_size(
+            b.first.c_str(), &mem_size_fixed, config_, compute_tp_);
       } else {
-        throw_if_not_ok(partition->get_est_result_size_nullable(
-            b.first.c_str(),
-            &size_fixed,
-            &size_validity,
-            config_,
-            compute_tp_));
-        throw_if_not_ok(partition->get_max_memory_size_nullable(
+        partition->get_est_result_size_nullable(
+            b.first.c_str(), &size_fixed, &size_validity, config_, compute_tp_);
+        partition->get_max_memory_size_nullable(
             b.first.c_str(),
             &mem_size_fixed,
             &mem_size_validity,
             config_,
-            compute_tp_));
+            compute_tp_);
       }
     }
 
@@ -1199,28 +1195,28 @@ bool SubarrayPartitioner::must_split(Subarray* partition) {
     if (!skip_split_on_est_size_) {
       if (var_size) {
         if (!nullable) {
-          throw_if_not_ok(partition->get_est_result_size(
-              b.first.c_str(), &size_fixed, &size_var, config_, compute_tp_));
+          partition->get_est_result_size(
+              b.first.c_str(), &size_fixed, &size_var, config_, compute_tp_);
         } else {
-          throw_if_not_ok(partition->get_est_result_size_nullable(
+          partition->get_est_result_size_nullable(
               b.first.c_str(),
               &size_fixed,
               &size_var,
               &size_validity,
               config_,
-              compute_tp_));
+              compute_tp_);
         }
       } else {
         if (!nullable) {
-          throw_if_not_ok(partition->get_est_result_size_internal(
-              b.first.c_str(), &size_fixed, config_, compute_tp_));
+          partition->get_est_result_size_internal(
+              b.first.c_str(), &size_fixed, config_, compute_tp_);
         } else {
-          throw_if_not_ok(partition->get_est_result_size_nullable(
+          partition->get_est_result_size_nullable(
               b.first.c_str(),
               &size_fixed,
               &size_validity,
               config_,
-              compute_tp_));
+              compute_tp_);
         }
       }
     }
@@ -1337,7 +1333,7 @@ Status SubarrayPartitioner::split_top_single_range(bool* unsplittable) {
 
   // Split remaining range into two ranges
   Subarray r1, r2;
-  RETURN_NOT_OK(range.split(splitting_dim, splitting_value, &r1, &r2));
+  range.split(splitting_dim, splitting_value, &r1, &r2);
 
   // Update list
   state_.single_range_.pop_front();
@@ -1380,8 +1376,7 @@ Status SubarrayPartitioner::split_top_multi_range(bool* unsplittable) {
   // Split partition into two partitions
   Subarray p1;
   Subarray p2;
-  RETURN_NOT_OK(partition.split(
-      splitting_range, splitting_dim, splitting_value, &p1, &p2));
+  partition.split(splitting_range, splitting_dim, splitting_value, &p1, &p2);
 
   // Update list
   state_.multi_range_.pop_front();
@@ -1436,7 +1431,7 @@ void SubarrayPartitioner::compute_range_uint64(
   for (uint32_t d = 0; d < dim_num; ++d) {
     auto dim{array_schema.dimension_ptr(d)};
     auto var = dim->var_size();
-    throw_if_not_ok(range.get_range(d, 0, &r));
+    range.get_range(d, 0, &r);
     empty_start = var ? (r->start_size() == 0) : r->empty();
     empty_end = var ? (r->end_size() == 0) : r->empty();
     auto max_default =
